assets

package
v0.0.0-...-d546383 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 19, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package assets provides special functionality for serving the Hypcast web frontend.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type FileSystem

type FileSystem struct {
	http.FileSystem
}

FileSystem wraps http.FileSystem to provide two extensions.

First, the root index page is served in place of a 404 for unknown paths. This supports single page applications that use client-side routing.

Second, directory listings are not served.

func (FileSystem) Open

func (fs FileSystem) Open(name string) (http.File, error)

Open implements http.FileSystem.

Jump to