Documentation
¶
Overview ¶
Package assets provides special functionality for serving the Hypcast web frontend.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FileSystem ¶
type FileSystem struct {
http.FileSystem
}
FileSystem wraps http.FileSystem to provide two extensions.
First, the root index page is served in place of a 404 for unknown paths. This supports single page applications that use client-side routing.
Second, directory listings are not served.
Click to show internal directories.
Click to hide internal directories.